==> jc-1.4.0.tar.gz: soot/jimple/parser/CstPoolExtractor.h <==
// class soot.jimple.parser.CstPoolExtractor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 12b5608acec0c8f9 soot_jimple_parser_CstPoolExtractor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_CstPoolExtractor_H_
#define _JC_soot_jimple_parser_CstPoolExtractor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_parser_CstPoolExtractor$object;
struct _jc_soot_jimple_parser_node_Start$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$sub_refs	_jc_soot_jimple_parser_CstPoolExtractor$sub_refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs	_jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$refs	_jc_soot_jimple_parser_CstPoolExtractor$refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$nonrefs	_jc_soot_jimple_parser_CstPoolExtractor$nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$object	_jc_soot_jimple_parser_CstPoolExtractor$object;

typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vmethods	_jc_soot_jimple_parser_CstPoolExtractor$vmethods;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vtable	_jc_soot_jimple_parser_CstPoolExtractor$vtable;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vtype	_jc_soot_jimple_parser_CstPoolExtractor$vtype;

// Constructors
extern void _jc_soot_jimple_parser_CstPoolExtractor$method$_init$f514ea09c5352517(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *, struct _jc_soot_jimple_parser_node_Start$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_parser_CstPoolExtractor$method$getCstPool$8a0a764b08f60ae5(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor$method_info$getCstPool$8a0a764b08f60ae5;

// Static methods
extern struct _jc_object *_jc_soot_jimple_parser_CstPoolExtractor$method$access__24000$3e0fb5fd5accbcd4(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_CstPoolExtractor$vmethods {
	struct _jc_object	*(*getCstPool$8a0a764b08f60ae5)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *);
};

// Vtable
struct _jc_soot_jimple_parser_CstPoolExtractor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_CstPoolExtractor$vmethods	soot_jimple_parser_CstPoolExtractor;
};

// Vtype
struct _jc_soot_jimple_parser_CstPoolExtractor$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_CstPoolExtractor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor$sub_refs {
	struct _jc_object	*mRefTypes;
	struct _jc_soot_jimple_parser_node_Start$object	*mParseTree;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor$refs {
    _jc_soot_jimple_parser_CstPoolExtractor$sub_refs	soot_jimple_parser_CstPoolExtractor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs	soot_jimple_parser_CstPoolExtractor;
};

// Object instance structure
struct _jc_soot_jimple_parser_CstPoolExtractor$object {
	_jc_soot_jimple_parser_CstPoolExtractor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_CstPoolExtractor$vtype	*vtype;
	_jc_soot_jimple_parser_CstPoolExtractor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_CstPoolExtractor$vtype _jc_soot_jimple_parser_CstPoolExtractor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_CstPoolExtractor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_CstPoolExtractor$class_object;

#endif	/* _JC_soot_jimple_parser_CstPoolExtractor_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/CstPoolExtractor.h <==
// class soot.jimple.parser.CstPoolExtractor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 12b5608acec0c8f9 soot_jimple_parser_CstPoolExtractor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_CstPoolExtractor_H_
#define _JC_soot_jimple_parser_CstPoolExtractor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_parser_CstPoolExtractor$object;
struct _jc_soot_jimple_parser_node_Start$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$sub_refs	_jc_soot_jimple_parser_CstPoolExtractor$sub_refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs	_jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$refs	_jc_soot_jimple_parser_CstPoolExtractor$refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$nonrefs	_jc_soot_jimple_parser_CstPoolExtractor$nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor$object	_jc_soot_jimple_parser_CstPoolExtractor$object;

typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vmethods	_jc_soot_jimple_parser_CstPoolExtractor$vmethods;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vtable	_jc_soot_jimple_parser_CstPoolExtractor$vtable;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor$vtype	_jc_soot_jimple_parser_CstPoolExtractor$vtype;

// Constructors
extern void _jc_soot_jimple_parser_CstPoolExtractor$method$_init$f514ea09c5352517(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *, struct _jc_soot_jimple_parser_node_Start$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_parser_CstPoolExtractor$method$getCstPool$8a0a764b08f60ae5(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor$method_info$getCstPool$8a0a764b08f60ae5;

// Static methods
extern struct _jc_object *_jc_soot_jimple_parser_CstPoolExtractor$method$access__24000$3e0fb5fd5accbcd4(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_CstPoolExtractor$vmethods {
	struct _jc_object	*(*getCstPool$8a0a764b08f60ae5)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_CstPoolExtractor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_CstPoolExtractor$vmethods	soot_jimple_parser_CstPoolExtractor;
};

// Vtype
struct _jc_soot_jimple_parser_CstPoolExtractor$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_CstPoolExtractor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor$sub_refs {
	struct _jc_object	*mRefTypes;
	struct _jc_soot_jimple_parser_node_Start$object	*mParseTree;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor$refs {
    _jc_soot_jimple_parser_CstPoolExtractor$sub_refs	soot_jimple_parser_CstPoolExtractor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_CstPoolExtractor$sub_nonrefs	soot_jimple_parser_CstPoolExtractor;
};

// Object instance structure
struct _jc_soot_jimple_parser_CstPoolExtractor$object {
	_jc_soot_jimple_parser_CstPoolExtractor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_CstPoolExtractor$vtype	*vtype;
	_jc_soot_jimple_parser_CstPoolExtractor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_CstPoolExtractor$vtype _jc_soot_jimple_parser_CstPoolExtractor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_CstPoolExtractor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_CstPoolExtractor$class_object;

#endif	/* _JC_soot_jimple_parser_CstPoolExtractor_H_ */
